#!/usr/bin/env python3 

import os
import sys
import site
import obt.path
import importlib.metadata
from obt.deco import Deco
deco = Deco()

def print_env_var(name, default):
    value = os.getenv(name, default)
    print(f"{deco.key(name)}: {deco.val(value)}")

def print_item(name, value):
    print(f"{deco.key(name)}: {deco.val(value)}")

print( "######################################################")

print_env_var(f'PYTHONPATH', sys.path)
print_env_var(f'PYTHONHOME', sys.prefix)
print_env_var(f'PYTHONSTARTUP', 'Not set')
print_env_var(f'PYTHONUSERBASE', site.USER_BASE)
print_env_var(f'PYTHONEXECUTABLE', sys.executable)
print_env_var(f'PYTHONWARNINGS', 'Not set')
print_env_var(f'PYTHONNOUSERSITE', 'Not set (User site directory is added to sys.path)')
print_env_var(f'PYTHONUNBUFFERED', 'Not set (Buffered I/O is used for stdout and stderr)')

print_env_var(f'site.PREFIXES', site.PREFIXES)
print_env_var(f'site.USER_SITE', site.USER_SITE)
print_env_var(f'site.USER_BASE', site.USER_BASE)
print_env_var(f'sys.prefix', sys.prefix)
print_env_var(f'sys.base_prefix', sys.base_prefix)

print( "######################################################")

a = importlib.metadata.distribution("ork.build").metadata

print_item( "obt-pymodule-path",obt.path.obt_module_path() )
print_item( "obt-data-base",obt.path.obt_data_base() )
print_item( "obt-modules-test",obt.path.__get_modules() )
print_item( "obt-test-inplace",obt.path.__is_inplace() )
print_item( "obt-modules-base",obt.path.obt_modules_base() )
print_item( "running_from_pip",obt.path.running_from_pip() )
print_item( "running_in_tree",obt.path.obt_in_tree() )
print_item( "obt.distrib.name",a["Name"] )
print_item( "obt.distrib.author",a["Author"] )
print_item( "obt.distrib.author-email",a["Author-email"] )
print_item( "obt.distrib.summary",a["Summary"] )
print_item( "obt.distrib.homepage",a["Home-page"] )
print( "################################################")
print_item( "obt.distrib.version",a["Version"] )


plist = os.environ.get("OBT_PROJECTS_LIST", "")
project_list = plist.split(":") if plist else []

def get_git_info():
  import git
  try:
    repo = git.Repo(search_parent_directories=True)
    hash = repo.head.object.hexsha
    is_dirty = repo.is_dirty(untracked_files=True)
    return hash, is_dirty
  except git.InvalidGitRepositoryError:
    return None, None    

for item in project_list:
  item = obt.path.Path(item)
  if item.exists():
    os.chdir(item)
    git_hash, is_dirty = get_git_info()
    if git_hash:
      status = "modified" if is_dirty else "clean"
      print_item(f"OBTGITPRJ: {item}", f"{git_hash[:8]} ({status})")
    else:
      print_item(f"OBTGITPRJ: {item}", f"not a repo")


#!/usr/bin/env python3

###############################################################################
# Orkid Build System
# Copyright 2010-2022, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################

import os, sys, pathlib, argparse, string
import obt._globals
import obt.docker
from obt import dep, path
from obt.deco import Deco
deco = Deco()

def print_item(key,val):
 dstr = deco.inf(dockerid)
 kstr = deco.key(key)
 vstr = deco.val(val)
 print("%s.%s = %s"%(dstr,kstr,vstr))

###############################################################################

parser = argparse.ArgumentParser(description='obt.build docker method invokation')
parser.add_argument('dockermodulename', metavar='D', type=str, help='a docker module to invoke method on')
parser.add_argument('--method', action="store", type=str, help='method to call' )

_args = vars(parser.parse_args())

if len(sys.argv)==1:
    print(parser.format_usage())
    sys.exit(1)

dockermodulename = _args["dockermodulename"]
method = _args["method"]

obt._globals.setOption("dockermodulename",dockermodulename)

print(dockermodulename)
print(method)

dockermodule = obt.docker.descriptor(dockermodulename)

h = getattr(dockermodule,method)

h()

#dockermodule.build()

sys.exit(0)